@@ -1,7 +1,6 @@
 #-----------------------------------------------------------------------------
-# Copyright (c) 2012 - 2017, Anaconda, Inc. All rights reserved.
-#
-# Powered by the Bokeh Development Team.
+# Copyright (c) 2012 - 2019, Anaconda, Inc., and Bokeh Contributors.
+# All rights reserved.
 #
 # The full license is in the file LICENSE.txt, distributed with this software.
 #-----------------------------------------------------------------------------
@@ -29,7 +28,7 @@ from os.path import abspath
 from tempfile import mkstemp
 
 # External imports
-from six import raise_from, b
+from six import raise_from
 
 # Bokeh imports
 from ..embed import file_html
@@ -57,11 +56,11 @@ __all__ = (
 # General API
 #-----------------------------------------------------------------------------
 
-def export_png(obj, filename=None, height=None, width=None, webdriver=None):
-    ''' Export the LayoutDOM object or document as a PNG.
+def export_png(obj, filename=None, height=None, width=None, webdriver=None, timeout=5):
+    ''' Export the ``LayoutDOM`` object or document as a PNG.
 
-    If the filename is not given, it is derived from the script name
-    (e.g. ``/foo/myplot.py`` will create ``/foo/myplot.png``)
+    If the filename is not given, it is derived from the script name (e.g.
+    ``/foo/myplot.py`` will create ``/foo/myplot.png``)
 
     Args:
         obj (LayoutDOM or Document) : a Layout (Row/Column), Plot or Widget
@@ -79,25 +78,35 @@ def export_png(obj, filename=None, height=None, width=None, webdriver=None):
         webdriver (selenium.webdriver) : a selenium webdriver instance to use
             to export the image.
 
+        timeout (int) : the maximum amount of time (in seconds) to wait for
+            Bokeh to initialize (default: 5) (Added in 1.1.1).
+
     Returns:
         filename (str) : the filename where the static file is saved.
 
+    If you would like to access an Image object directly, rather than save a
+    file to disk, use the lower-level :func:`~bokeh.io.export.get_screenshot_as_png`
+    function.
+
     .. warning::
         Responsive sizing_modes may generate layouts with unexpected size and
         aspect ratios. It is recommended to use the default ``fixed`` sizing mode.
 
     '''
 
-    image = get_screenshot_as_png(obj, height=height, width=width, driver=webdriver)
+    image = get_screenshot_as_png(obj, height=height, width=width, driver=webdriver, timeout=timeout)
 
     if filename is None:
         filename = default_filename("png")
 
+    if image.width == 0 or image.height == 0:
+        raise ValueError("unable to save an empty image")
+
     image.save(filename)
 
     return abspath(filename)
 
-def export_svgs(obj, filename=None, height=None, width=None, webdriver=None):
+def export_svgs(obj, filename=None, height=None, width=None, webdriver=None, timeout=5):
     ''' Export the SVG-enabled plots within a layout. Each plot will result
     in a distinct SVG file.
 
@@ -119,16 +128,19 @@ def export_svgs(obj, filename=None, height=None, width=None, webdriver=None):
         webdriver (selenium.webdriver) : a selenium webdriver instance to use
             to export the image.
 
+        timeout (int) : the maximum amount of time (in seconds) to wait for
+            Bokeh to initialize (default: 5) (Added in 1.1.1).
+
     Returns:
-        filenames (list(str)) : the list of filenames where the SVGs files
-            are saved.
+        filenames (list(str)) : the list of filenames where the SVGs files are
+        saved.
 
     .. warning::
         Responsive sizing_modes may generate layouts with unexpected size and
         aspect ratios. It is recommended to use the default ``fixed`` sizing mode.
 
     '''
-    svgs = get_svgs(obj, height=height, width=width, driver=webdriver)
+    svgs = get_svgs(obj, height=height, width=width, driver=webdriver, timeout=timeout)
 
     if len(svgs) == 0:
         log.warning("No SVG Plots were found.")
@@ -164,15 +176,15 @@ from .webdriver import terminate_webdriver # for back compat
 def create_webdriver():
     ''' Create a new webdriver.
 
-    ..note ::
-        Here for compatiboility. Prefer methods on the webdriver_control
+    .. note ::
+        Here for compatibility. Prefer methods on the webdriver_control
         object.
 
     '''
     return webdriver_control.create()
 
-def get_screenshot_as_png(obj, driver=None, **kwargs):
-    ''' Get a screenshot of a LayoutDOM object.
+def get_screenshot_as_png(obj, driver=None, timeout=5, **kwargs):
+    ''' Get a screenshot of a ``LayoutDOM`` object.
 
     Args:
         obj (LayoutDOM or Document) : a Layout (Row/Column), Plot or Widget
@@ -181,6 +193,10 @@ def get_screenshot_as_png(obj, driver=None, **kwargs):
         driver (selenium.webdriver) : a selenium webdriver instance to use
             to export the image.
 
+        timeout (int) : the maximum amount of time to wait for initialization.
+            It will be used as a timeout for loading Bokeh, then when waiting for
+            the layout to be rendered.
+
     Returns:
         cropped_image (PIL.Image.Image) : a pillow image loaded from PNG.
 
@@ -206,7 +222,7 @@ def get_screenshot_as_png(obj, driver=None, **kwargs):
         ## resize for PhantomJS compat
         web_driver.execute_script("document.body.style.width = '100%';")
 
-        wait_until_render_complete(web_driver)
+        wait_until_render_complete(web_driver, timeout)
 
         png = web_driver.get_screenshot_as_png()
 
@@ -217,20 +233,20 @@ def get_screenshot_as_png(obj, driver=None, **kwargs):
 
     return cropped_image
 
-def get_svgs(obj, driver=None, **kwargs):
+def get_svgs(obj, driver=None, timeout=5, **kwargs):
     '''
 
     '''
     with _tmp_html() as tmp:
         html = get_layout_html(obj, **kwargs)
-        with io.open(tmp.path, mode="wb") as file:
-            file.write(b(html))
+        with io.open(tmp.path, mode="w", encoding="utf-8") as file:
+            file.write(decode_utf8(html))
 
         web_driver = driver if driver is not None else webdriver_control.get()
 
         web_driver.get("file:///" + tmp.path)
 
-        wait_until_render_complete(web_driver)
+        wait_until_render_complete(web_driver, timeout)
 
         svgs = web_driver.execute_script(_SVG_SCRIPT)
 
@@ -254,7 +270,7 @@ def get_layout_html(obj, resources=INLINE, **kwargs):
             obj.plot_width = kwargs.get('width', old_width)
 
     try:
-        html = file_html(obj, resources, title="", suppress_callback_warning=True)
+        html = file_html(obj, resources, title="", suppress_callback_warning=True, _always_new=True)
     finally:
         if resize:
             obj.plot_height = old_height
@@ -262,12 +278,13 @@ def get_layout_html(obj, resources=INLINE, **kwargs):
 
     return html
 
-def wait_until_render_complete(driver):
+def wait_until_render_complete(driver, timeout):
     '''
 
     '''
     from selenium.webdriver.support.ui import WebDriverWait
     from selenium.common.exceptions import TimeoutException
+    from selenium.webdriver import Firefox
 
     def is_bokeh_loaded(driver):
         return driver.execute_script('''
@@ -276,7 +293,7 @@ def wait_until_render_complete(driver):
         ''')
 
     try:
-        WebDriverWait(driver, 5, poll_frequency=0.1).until(is_bokeh_loaded)
+        WebDriverWait(driver, timeout, poll_frequency=0.1).until(is_bokeh_loaded)
     except TimeoutException as e:
         raise_from(RuntimeError('Bokeh was not loaded in time. Something may have gone wrong.'), e)
 
@@ -286,16 +303,20 @@ def wait_until_render_complete(driver):
         return driver.execute_script('return window._bokeh_render_complete;')
 
     try:
-        WebDriverWait(driver, 5, poll_frequency=0.1).until(is_bokeh_render_complete)
+        WebDriverWait(driver, timeout, poll_frequency=0.1).until(is_bokeh_render_complete)
     except TimeoutException:
-        log.warning("The webdriver raised a TimeoutException while waiting for \
-                     a 'bokeh:idle' event to signify that the layout has rendered. \
-                     Something may have gone wrong.")
+        log.warning("The webdriver raised a TimeoutException while waiting for "
+                    "a 'bokeh:idle' event to signify that the layout has rendered. "
+                    "Something may have gone wrong.")
     finally:
-        browser_logs = driver.get_log('browser')
-        severe_errors = [l for l in browser_logs if l.get('level') == 'SEVERE']
-        if len(severe_errors) > 0:
-            log.warning("There were severe browser errors that may have affected your export: {}".format(severe_errors))
+        # Firefox webdriver does not currently support logs
+        if not isinstance(driver, Firefox):
+            browser_logs = driver.get_log('browser')
+            messages = [ l.get("message") for l in browser_logs if l.get('level') in ['WARNING', 'ERROR', 'SEVERE'] ]
+            if len(messages) > 0:
+                log.warning("There were browser warnings and/or errors that may have affected your export")
+                for message in messages:
+                    log.warning(message)
 
 #-----------------------------------------------------------------------------
 # Private API
