@@ -1,7 +1,6 @@
 #-----------------------------------------------------------------------------
-# Copyright (c) 2012 - 2018, Anaconda, Inc. All rights reserved.
-#
-# Powered by the Bokeh Development Team.
+# Copyright (c) 2012 - 2019, Anaconda, Inc., and Bokeh Contributors.
+# All rights reserved.
 #
 # The full license is in the file LICENSE.txt, distributed with this software.
 #-----------------------------------------------------------------------------
@@ -53,8 +52,10 @@ from bokeh.models.annotations import (
 
 def test_Legend():
     legend = Legend()
-    assert legend.plot is None
     assert legend.location == 'top_right'
+    assert legend.orientation == 'vertical'
+    assert legend.title is None
+    assert legend.title_standoff == 5
     assert legend.label_standoff == 5
     assert legend.label_height == 20
     assert legend.label_width == 20
@@ -68,10 +69,11 @@ def test_Legend():
     check_text_properties(legend, "label_", "10pt", "middle")
     check_fill_properties(legend, "background_", "#ffffff", 0.95)
     check_properties_existence(legend, [
-        "plot",
         "visible",
         "location",
         "orientation",
+        "title",
+        "title_standoff",
         "label_standoff",
         "label_height",
         "label_width",
@@ -84,6 +86,7 @@ def test_Legend():
         "level",
         "click_policy"],
         prefix('label_', TEXT),
+        prefix('title_', TEXT),
         prefix('border_', LINE),
         prefix('background_', FILL),
         prefix('inactive_', FILL))
@@ -91,7 +94,6 @@ def test_Legend():
 
 def test_ColorBar():
     color_bar = ColorBar()
-    assert color_bar.plot is None
     assert color_bar.location == 'top_right'
     assert color_bar.orientation == 'vertical'
     assert color_bar.height == 'auto'
@@ -117,7 +119,6 @@ def test_ColorBar():
     check_line_properties(color_bar, "border_", None)
     check_fill_properties(color_bar, "background_", "#ffffff", 0.95)
     check_properties_existence(color_bar, [
-        "plot",
         "level",
         "visible",
         "location",
@@ -150,7 +151,6 @@ def test_ColorBar():
 
 def test_Arrow():
     arrow = Arrow()
-    assert arrow.plot is None
     assert arrow.x_start is None
     assert arrow.y_start is None
     assert arrow.start_units == 'data'
@@ -164,7 +164,6 @@ def test_Arrow():
     assert arrow.y_range_name == "default"
     check_line_properties(arrow)
     check_properties_existence(arrow, [
-        "plot",
         "level",
         "visible",
         "x_start",
@@ -183,7 +182,6 @@ def test_Arrow():
 
 def test_BoxAnnotation():
     box = BoxAnnotation()
-    assert box.plot is None
     assert box.left is None
     assert box.left_units == 'data'
     assert box.right is None
@@ -199,7 +197,6 @@ def test_BoxAnnotation():
     check_fill_properties(box, "", "#fff9ba", 0.4)
     check_properties_existence(box, [
         "render_mode",
-        "plot",
         "visible",
         "left",
         "left_units",
@@ -217,7 +214,6 @@ def test_BoxAnnotation():
 
 def test_Band():
     band = Band()
-    assert band.plot is None
     assert band.level == 'annotation'
     assert band.lower is None
     assert band.lower_units == 'data'
@@ -231,7 +227,6 @@ def test_Band():
     check_line_properties(band, "", "#cccccc", 1.0, 0.3)
     check_fill_properties(band, "", "#fff9ba", 0.4)
     check_properties_existence(band, [
-        "plot",
         "visible",
         "level",
         "lower",
@@ -249,7 +244,6 @@ def test_Band():
 
 def test_Label():
     label = Label()
-    assert label.plot is None
     assert label.level == 'annotation'
     assert label.x is None
     assert label.y is None
@@ -267,7 +261,6 @@ def test_Label():
     check_fill_properties(label, "background_", None, 1.0)
     check_line_properties(label, "border_", None, 1.0, 1.0)
     check_properties_existence(label, [
-        "plot",
         "level",
         "visible",
         "x",
@@ -294,7 +287,6 @@ def test_Label_accepts_datetime_xy():
 
 def test_LabelSet():
     label_set = LabelSet()
-    assert label_set.plot is None
     assert label_set.level == 'annotation'
     assert label_set.x is None
     assert label_set.y is None
@@ -314,7 +306,6 @@ def test_LabelSet():
     check_fill_properties(label_set, "background_", None, 1.0)
     check_line_properties(label_set, "border_", None, 1.0, 1.0)
     check_properties_existence(label_set, [
-        "plot",
         "visible",
         "level",
         "x",
@@ -337,7 +328,6 @@ def test_LabelSet():
 
 def test_Slope():
     slope = Slope()
-    assert slope.plot is None
     assert slope.gradient is None
     assert slope.y_intercept is None
     assert slope.x_range_name == 'default'
@@ -345,7 +335,6 @@ def test_Slope():
     assert slope.level == 'annotation'
     check_line_properties(slope, "", 'black', 1.0)
     check_properties_existence(slope, [
-        "plot",
         "visible",
         "gradient",
         "y_intercept",
@@ -357,7 +346,6 @@ def test_Slope():
 
 def test_Span():
     line = Span()
-    assert line.plot is None
     assert line.location is None
     assert line.location_units == 'data'
     assert line.dimension == 'width'
@@ -367,7 +355,6 @@ def test_Span():
     assert line.render_mode == 'canvas'
     check_line_properties(line, "", 'black', 1.0)
     check_properties_existence(line, [
-        "plot",
         "visible",
         "location",
         "location_units",
@@ -384,7 +371,6 @@ def test_Span_accepts_datetime_location():
 
 def test_Title():
     title = Title()
-    assert title.plot is None
     assert title.level == 'annotation'
     assert title.text is None
     assert title.vertical_align == 'bottom'
@@ -395,10 +381,10 @@ def test_Title():
     assert title.text_font_style == 'bold'
     assert title.text_color == '#444444'
     assert title.text_alpha == 1.0
+    assert title.text_line_height == 1.0
     check_fill_properties(title, "background_", None, 1.0)
     check_line_properties(title, "border_", None, 1.0, 1.0)
     check_properties_existence(title, [
-        "plot",
         "visible",
         "level",
         "text",
@@ -410,6 +396,7 @@ def test_Title():
         "text_font_style",
         "text_color",
         "text_alpha",
+        "text_line_height",
         "render_mode"],
         prefix('border_', LINE),
         prefix('background_', FILL))
@@ -417,7 +404,6 @@ def test_Title():
 
 def test_Whisker():
     whisker = Whisker()
-    assert whisker.plot is None
     assert whisker.level == 'underlay'
     assert whisker.lower is None
     assert whisker.lower_units == 'data'
@@ -436,7 +422,6 @@ def test_Whisker():
     assert whisker.y_range_name == 'default'
     check_line_properties(whisker, "")
     check_properties_existence(whisker, [
-        "plot",
         "visible",
         "level",
         "lower",
@@ -453,6 +438,15 @@ def test_Whisker():
         "y_range_name"],
         LINE)
 
+def test_Whisker_and_Band_accept_negative_values():
+    whisker = Whisker(base=-1., lower=-1.5, upper=-0.5)
+    assert whisker.base == -1.
+    assert whisker.lower == -1.5
+    assert whisker.upper == -0.5
+    band = Band(base=-1., lower=-1.5, upper=-0.5)
+    assert band.base == -1.
+    assert band.lower == -1.5
+    assert band.upper == -0.5
 
 def test_can_add_multiple_glyph_renderers_to_legend_item():
     legend_item = LegendItem()
