@@ -1,7 +1,6 @@
 #-----------------------------------------------------------------------------
-# Copyright (c) 2012 - 2018, Anaconda, Inc. All rights reserved.
-#
-# Powered by the Bokeh Development Team.
+# Copyright (c) 2012 - 2019, Anaconda, Inc., and Bokeh Contributors.
+# All rights reserved.
 #
 # The full license is in the file LICENSE.txt, distributed with this software.
 #-----------------------------------------------------------------------------
@@ -21,10 +20,11 @@ import pytest ; pytest
 from datetime import timedelta
 import logging
 import re
+import ssl
 import sys
-import mock
 
 # External imports
+import mock
 from tornado import gen
 from tornado.ioloop import PeriodicCallback, IOLoop
 from tornado.httpclient import HTTPError
@@ -173,6 +173,14 @@ def test_prefix():
     with ManagedServerLoop(application, prefix="foo") as server:
         assert server.prefix == "foo"
 
+def test_index():
+    application = Application()
+    with ManagedServerLoop(application) as server:
+        assert server.index is None
+
+    with ManagedServerLoop(application, index="foo") as server:
+        assert server.index == "foo"
+
 def test_get_sessions():
     application = Application()
     with ManagedServerLoop(application) as server:
@@ -254,7 +262,6 @@ def resource_files_requested(response, requested=True):
         import codecs
         response = codecs.decode(response, 'utf-8')
     for file in [
-        'static/css/bokeh.min.css', 'static/css/bokeh-widgets.min.css',
         'static/js/bokeh.min.js', 'static/js/bokeh-widgets.min.js']:
         if requested:
             assert file in response
@@ -266,6 +273,22 @@ def test_use_xheaders():
     with ManagedServerLoop(application, use_xheaders=True) as server:
         assert server._http.xheaders == True
 
+def test_ssl_args_plumbing():
+    with mock.patch.object(ssl, 'SSLContext'):
+        with ManagedServerLoop({}, ssl_certfile="foo") as server:
+            assert server._http.ssl_options.load_cert_chain.call_args[0] == ()
+            assert server._http.ssl_options.load_cert_chain.call_args[1] == dict(certfile='foo', keyfile=None, password=None)
+
+    with mock.patch.object(ssl, 'SSLContext'):
+        with ManagedServerLoop({}, ssl_certfile="foo", ssl_keyfile="baz") as server:
+            assert server._http.ssl_options.load_cert_chain.call_args[0] == ()
+            assert server._http.ssl_options.load_cert_chain.call_args[1] == dict(certfile='foo', keyfile="baz", password=None)
+
+    with mock.patch.object(ssl, 'SSLContext'):
+        with ManagedServerLoop({}, ssl_certfile="foo", ssl_keyfile="baz", ssl_password="bar") as server:
+            assert server._http.ssl_options.load_cert_chain.call_args[0] == ()
+            assert server._http.ssl_options.load_cert_chain.call_args[1] == dict(certfile='foo', keyfile="baz", password="bar")
+
 # This test just maintains basic creation and setup, detailed functionality
 # is exercised by Server tests above
 def test_base_server():
@@ -659,7 +682,7 @@ def test__server_multiple_processes():
             application = Application()
             server.Server(application, num_procs=3, port=0)
 
-        tornado_fp.assert_called_with(3)
+        tornado_fp.assert_called_with(3, mock.ANY)
 
 def test__existing_ioloop_with_multiple_processes_exception():
     application = Application()
